Experiment Exports — Map of Objects

Skip to main content
`Ctrl`+`K`

# Experiment Exports

export_distances_multiple_processes(experiment, instances_ids, distances, times, process_id) → None

  Exports distances between each pair of instances to a .csv file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - instances_ids – List of the Ids.

    - distances (dict) – Dictionary with distances between each pair of instances

    - times (dict) – Dictionary with time of calculation of each distance.

    - process_id (bool) – ID of the process.

  Return type:

    None

export_distances_to_file(experiment, distance_id: str, distances: dict[str, dict[str, int]], times: dict[str, dict[str, int]], ids=None) → None

  Exports distances between each pair of instances to a .csv file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - distance_id (str) – Name of the distance.

    - distances (dict[str, dict[str, int]]) – Dictionary with distances between each pair of instances

    - times (dict[str, dict[str, int]]) – Dictionary with time of calculation of each distance.

    - ids – List of the Ids.

  Return type:

    None

export_embedding_to_file(experiment, embedding_id: str, saveas: str, dim: int, my_pos) → None

  Exports coordinates of all instances to a .csv file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - embedding_id (str) – Name of the embedding.

    - saveas (str) – Name of the file to save the feature to.

    - dim (int) – Dimension of the embedding.

    - my_pos – list of coordinates

  Return type:

    None

export_feature_to_file(experiment, feature_id: str, feature_dict: dict | None = None, saveas: str | None = None) → None

  Exports feature to a .csv file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - feature_id (str) – Name of the feature.

    - feature_dict (dict) – Dictionary with feature values.

    - saveas (str) – Name of the file to save the feature to.

  Return type:

    None

export_normalized_feature_to_file(experiment, feature_dict: dict | None = None, saveas: str | None = None) → None

  Exports normalized feature to a .csv file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - feature_dict (dict) – Dictionary with feature values.

    - saveas (str) – Name of the file to save the feature to.

  Return type:

    None